pitchtools.transpose_pitch_number_by_octave_transposition_mapping
=================================================================

.. autofunction:: abjad.tools.pitchtools.transpose_pitch_number_by_octave_transposition_mapping.transpose_pitch_number_by_octave_transposition_mapping
